@@ -29,7 +29,6 @@
 #include "checks/level0/qstring-arg.h"
 #include "checks/level0/qstring-comparison-to-implicit-char.h"
 #include "checks/level0/qstring-insensitive-allocation.h"
-#include "checks/level0/qstring-ref.h"
 #include "checks/level0/qt-macros.h"
 #include "checks/level0/strict-iterators.h"
 #include "checks/level0/temporary-iterator.h"
@@ -77,6 +76,7 @@
 #include "checks/level2/static-pmf.h"
 #include "checks/level2/virtual-call-ctor.h"
 #include "checks/manuallevel/assert-with-side-effects.h"
+#include "checks/manuallevel/compare-member-check.h"
 #include "checks/manuallevel/container-inside-loop.h"
 #include "checks/manuallevel/detaching-member.h"
 #include "checks/manuallevel/heap-allocated-small-trivial-type.h"
@@ -87,14 +87,10 @@
 #include "checks/manuallevel/qhash-with-char-pointer-key.h"
 #include "checks/manuallevel/qproperty-type-mismatch.h"
 #include "checks/manuallevel/qrequiredresult-candidates.h"
+#include "checks/manuallevel/qstring-ref.h"
 #include "checks/manuallevel/qstring-varargs.h"
 #include "checks/manuallevel/qt-keyword-emit.h"
 #include "checks/manuallevel/qt-keywords.h"
-#include "checks/manuallevel/qt6-deprecated-api-fixes.h"
-#include "checks/manuallevel/qt6-fwd-fixes.h"
-#include "checks/manuallevel/qt6-header-fixes.h"
-#include "checks/manuallevel/qt6-qhash-signature.h"
-#include "checks/manuallevel/qt6-qlatin1stringchar-to-u.h"
 #include "checks/manuallevel/qvariant-template-instantiation.h"
 #include "checks/manuallevel/raw-environment-function.h"
 #include "checks/manuallevel/reserve-candidates.h"
@@ -122,6 +118,7 @@ RegisteredCheck check(const char *name, CheckLevel level, RegisteredCheck::Optio
 void CheckManager::registerChecks()
 {
     registerCheck(check<AssertWithSideEffects>("assert-with-side-effects", ManualCheckLevel, RegisteredCheck::Option_VisitsStmts, true));
+    registerCheck(check<CompareMemberCheck>("compare-member-check", ManualCheckLevel, RegisteredCheck::Option_None, true));
     registerCheck(check<ContainerInsideLoop>("container-inside-loop", ManualCheckLevel, RegisteredCheck::Option_VisitsStmts, true));
     registerCheck(check<DetachingMember>("detaching-member", ManualCheckLevel, RegisteredCheck::Option_VisitsStmts, true));
     registerCheck(check<HeapAllocatedSmallTrivialType>("heap-allocated-small-trivial-type", ManualCheckLevel, RegisteredCheck::Option_VisitsDecls, false));
@@ -133,21 +130,13 @@ void CheckManager::registerChecks()
     registerCheck(check<QHashWithCharPointerKey>("qhash-with-char-pointer-key", ManualCheckLevel, RegisteredCheck::Option_VisitsDecls, false));
     registerCheck(check<QPropertyTypeMismatch>("qproperty-type-mismatch", ManualCheckLevel, RegisteredCheck::Option_VisitsDecls | RegisteredCheck::Option_PreprocessorCallbacks | RegisteredCheck::Option_VisitAllTypeDefs, false));
     registerCheck(check<QRequiredResultCandidates>("qrequiredresult-candidates", ManualCheckLevel, RegisteredCheck::Option_VisitsDecls, false));
+    registerCheck(check<StringRefCandidates>("qstring-ref", ManualCheckLevel, RegisteredCheck::Option_VisitsStmts, true));
+    registerFixIt(1, "fix-missing-qstringref", "qstring-ref");
     registerCheck(check<QStringVarargs>("qstring-varargs", ManualCheckLevel, RegisteredCheck::Option_VisitsStmts, true));
     registerCheck(check<QtKeywordEmit>("qt-keyword-emit", ManualCheckLevel, RegisteredCheck::Option_PreprocessorCallbacks, false));
     registerFixIt(1, "fix-qt-keyword-emit", "qt-keyword-emit");
     registerCheck(check<QtKeywords>("qt-keywords", ManualCheckLevel, RegisteredCheck::Option_PreprocessorCallbacks, false));
     registerFixIt(1, "fix-qt-keywords", "qt-keywords");
-    registerCheck(check<Qt6DeprecatedAPIFixes>("qt6-deprecated-api-fixes", ManualCheckLevel, RegisteredCheck::Option_VisitsStmts | RegisteredCheck::Option_VisitsDecls | RegisteredCheck::Option_PreprocessorCallbacks, true));
-    registerFixIt(1, "fix-qt6-deprecated-api-fixes", "qt6-deprecated-api-fixes");
-    registerCheck(check<Qt6FwdFixes>("qt6-fwd-fixes", ManualCheckLevel, RegisteredCheck::Option_VisitsDecls | RegisteredCheck::Option_PreprocessorCallbacks, true));
-    registerFixIt(1, "fix-qt6-fwd-fixes", "qt6-fwd-fixes");
-    registerCheck(check<Qt6HeaderFixes>("qt6-header-fixes", ManualCheckLevel, RegisteredCheck::Option_VisitsStmts | RegisteredCheck::Option_PreprocessorCallbacks, true));
-    registerFixIt(1, "fix-qt6-header-fixes", "qt6-header-fixes");
-    registerCheck(check<Qt6QHashSignature>("qt6-qhash-signature", ManualCheckLevel, RegisteredCheck::Option_VisitsStmts | RegisteredCheck::Option_VisitsDecls, true));
-    registerFixIt(1, "fix-qt6-qhash-signature", "qt6-qhash-signature");
-    registerCheck(check<Qt6QLatin1StringCharToU>("qt6-qlatin1stringchar-to-u", ManualCheckLevel, RegisteredCheck::Option_VisitsStmts | RegisteredCheck::Option_PreprocessorCallbacks, true));
-    registerFixIt(1, "fix-qt6-qlatin1stringchar-to-u", "qt6-qlatin1stringchar-to-u");
     registerCheck(check<QVariantTemplateInstantiation>("qvariant-template-instantiation", ManualCheckLevel, RegisteredCheck::Option_VisitsStmts, true));
     registerCheck(check<RawEnvironmentFunction>("raw-environment-function", ManualCheckLevel, RegisteredCheck::Option_VisitsStmts, false));
     registerCheck(check<ReserveCandidates>("reserve-candidates", ManualCheckLevel, RegisteredCheck::Option_VisitsStmts, true));
@@ -188,8 +177,6 @@ void CheckManager::registerChecks()
     registerCheck(check<QStringArg>("qstring-arg", CheckLevel0, RegisteredCheck::Option_VisitsStmts, true));
     registerCheck(check<QStringComparisonToImplicitChar>("qstring-comparison-to-implicit-char", CheckLevel0, RegisteredCheck::Option_VisitsStmts, false));
     registerCheck(check<QStringInsensitiveAllocation>("qstring-insensitive-allocation", CheckLevel0, RegisteredCheck::Option_VisitsStmts, true));
-    registerCheck(check<StringRefCandidates>("qstring-ref", CheckLevel0, RegisteredCheck::Option_VisitsStmts, true));
-    registerFixIt(1, "fix-missing-qstringref", "qstring-ref");
     registerCheck(check<QtMacros>("qt-macros", CheckLevel0, RegisteredCheck::Option_PreprocessorCallbacks, false));
     registerCheck(check<StrictIterators>("strict-iterators", CheckLevel0, RegisteredCheck::Option_VisitsStmts, true));
     registerCheck(check<TemporaryIterator>("temporary-iterator", CheckLevel0, RegisteredCheck::Option_VisitsStmts, false));
