@@ -70,7 +70,9 @@ std::string clazy::getMostNeededQualifiedName(const SourceManager &sourceManager
     std::vector<UsingDirectiveDecl *> usings;
     if (honourUsingDirectives) {
         for (DeclContext *context : visibleContexts) {
-            clazy::append(context->using_directives(), usings);
+            for (UsingDirectiveDecl *directive : context->using_directives()) {
+                usings.push_back(directive);
+            }
         }
     }
 
@@ -86,7 +88,7 @@ std::string clazy::getMostNeededQualifiedName(const SourceManager &sourceManager
 
     for (DeclContext *context : visibleContexts) {
         if (context != method->getParent()) { // Don't remove the most immediate
-            auto it = clazy::find_if(methodContexts, [context](DeclContext *c) {
+            auto it = std::ranges::find_if(methodContexts, [context](DeclContext *c) {
                 if (c == context) {
                     return true;
                 }
