@@ -78,7 +78,7 @@ tooling::Diagnostic FixItExporter::ConvertDiagnostic(const Diagnostic &Info)
     // TODO: This returns an empty string: DiagEngine->getDiagnosticIDs()->getWarningOptionForDiag(Info.getID());
     // HACK: capture it at the end of the message: Message text [check-name]
 
-    std::string checkName = static_cast<std::string>(DiagEngine.getDiagnosticIDs()->getWarningOptionForDiag(Info.getID()));
+    std::string checkName = DiagEngine.getDiagnosticIDs()->getWarningOptionForDiag(Info.getID()).str();
     std::string messageText;
 
     if (checkName.empty()) {
@@ -120,13 +120,14 @@ tooling::Replacement FixItExporter::ConvertFixIt(const FixItHint &Hint)
             }
             clang::SourceLocation e(clang::Lexer::getLocForEndOfToken(_e, 0, SourceMgr, LangOpts));
             StringRef Text(SourceMgr.getCharacterData(b), SourceMgr.getCharacterData(e) - SourceMgr.getCharacterData(b));
-            return tooling::Replacement(SourceMgr, Hint.RemoveRange, Text);
+            return {SourceMgr, Hint.RemoveRange, Text};
         }
-        return tooling::Replacement(SourceMgr, Hint.RemoveRange, "");
+        return {SourceMgr, Hint.RemoveRange, ""};
     }
-    return tooling::Replacement(SourceMgr, Hint.RemoveRange, Hint.CodeToInsert);
+    return {SourceMgr, Hint.RemoveRange, Hint.CodeToInsert};
 }
 
+// This function should export diagnostics, even if they are not fixits! Needed for Qtcreator integration
 void FixItExporter::HandleDiagnostic(DiagnosticsEngine::Level DiagLevel, const Diagnostic &Info)
 {
     // Default implementation (Warnings/errors count).
