@@ -25,6 +25,16 @@ bool clazy::isQtIterableClass(clang::CXXRecordDecl *record)
     return record && isQtIterableClass(record->getQualifiedNameAsString());
 }
 
+std::string trimQtNamespace(const std::string &name, const std::string qtNamespace)
+{
+    if (!qtNamespace.empty() && name.starts_with(qtNamespace + "::")) {
+        std::string nameCopy = name;
+        nameCopy.erase(0, qtNamespace.size() + 2);
+        return nameCopy;
+    }
+    return name;
+}
+
 const std::vector<StringRef> &clazy::qtContainers()
 {
     static const std::vector<StringRef> classes = {
@@ -122,7 +132,7 @@ std::unordered_map<std::string, std::vector<clazy::MemberConstcounterpartPair>>
             {"first", "constFirst"},
             {"find", "constFind"},
             {"last", "constLast"},
-            {"operator[]", "at"},
+            {"operator[]", "value"},
             {"lowerBound", "lowerBound"}, // const overload exists, same name
             {"upperBound", "upperBound"},
             {"keyValueBegin", "constKeyValueBegin"},
@@ -168,7 +178,7 @@ std::unordered_map<std::string, std::vector<clazy::MemberConstcounterpartPair>>
     return map;
 }
 
-bool clazy::isQMetaMethod(CallExpr *Call, unsigned int argIndex)
+bool clazy::isQMetaMethod(CallExpr *Call, unsigned int argIndex, const std::string &qtNamespace)
 {
     Expr *arg = Call->getArg(argIndex);
     QualType type = arg->getType();
@@ -181,18 +191,18 @@ bool clazy::isQMetaMethod(CallExpr *Call, unsigned int argIndex)
         return false;
     }
 
-    return recordDecl->getQualifiedNameAsString() == "QMetaMethod";
+    return recordDecl->getQualifiedNameAsString() == clazy::qtNamespaced("QMetaMethod", qtNamespace);
 }
 
-bool clazy::isQtCOWIterableClass(clang::CXXRecordDecl *record)
+bool clazy::isQtCOWIterableClass(clang::CXXRecordDecl *record, const std::string &qtNamespace)
 {
-    return record && isQtCOWIterableClass(record->getQualifiedNameAsString());
+    return record && isQtCOWIterableClass(record->getQualifiedNameAsString(), qtNamespace);
 }
 
-bool clazy::isQtCOWIterableClass(const std::string &className)
+bool clazy::isQtCOWIterableClass(const std::string &className, const std::string &qtNamespace)
 {
     const auto &classes = qtCOWContainers();
-    return clazy::contains(classes, className);
+    return clazy::contains(classes, trimQtNamespace(className, qtNamespace));
 }
 
 bool clazy::isQtIterableClass(StringRef className)
@@ -212,16 +222,14 @@ bool clazy::isQtAssociativeContainer(StringRef className)
     return clazy::contains(classes, className);
 }
 
-bool clazy::isQObject(const CXXRecordDecl *decl)
+bool clazy::isQObject(const CXXRecordDecl *decl, const std::string &qtNamespace)
 {
-    return clazy::derivesFrom(decl, "QObject");
+    return clazy::derivesFrom(decl, clazy::qtNamespaced("QObject", qtNamespace));
 }
-
-bool clazy::isQObject(clang::QualType qt)
+bool clazy::isSharedPointer(CXXRecordDecl *record, const std::string &qtNamespace)
 {
-    qt = clazy::pointeeQualType(qt);
-    const auto *const t = qt.getTypePtrOrNull();
-    return t ? isQObject(t->getAsCXXRecordDecl()) : false;
+    static const std::vector<std::string> names = {"std::shared_ptr", "QSharedPointer", "boost::shared_ptr"};
+    return record ? clazy::contains(names, trimQtNamespace(record->getQualifiedNameAsString(), qtNamespace)) : false;
 }
 
 bool clazy::isConvertibleTo(const Type *source, const Type *target)
@@ -294,31 +302,36 @@ bool clazy::isQtContainer(QualType t)
 bool clazy::isQtContainer(const CXXRecordDecl *record)
 {
     const StringRef typeName = clazy::name(record);
-    return clazy::any_of(clazy::qtContainers(), [typeName](StringRef container) {
+    return std::ranges::any_of(clazy::qtContainers(), [typeName](StringRef container) {
         return container == typeName;
     });
 }
 
-bool clazy::isAReserveClass(CXXRecordDecl *recordDecl)
+bool clazy::isAReserveClass(CXXRecordDecl *recordDecl, const std::string &qtNamespace)
 {
     if (!recordDecl) {
         return false;
     }
 
-    static const std::vector<std::string> classes = {"QVector", "std::vector", "QList", "QSet"};
-    return clazy::any_of(classes, [recordDecl](const std::string &className) {
+    static const std::vector<std::string> classes = {
+        clazy::qtNamespaced("QVector", qtNamespace),
+        "std::vector",
+        clazy::qtNamespaced("QList", qtNamespace),
+        clazy::qtNamespaced("QSet", qtNamespace),
+    };
+    return std::ranges::any_of(classes, [recordDecl](const std::string &className) {
         return clazy::derivesFrom(recordDecl, className);
     });
 }
 
-clang::CXXRecordDecl *clazy::getQObjectBaseClass(clang::CXXRecordDecl *recordDecl)
+clang::CXXRecordDecl *clazy::getQObjectBaseClass(clang::CXXRecordDecl *recordDecl, const std::string &qtNamespace)
 {
     if (!recordDecl) {
         return nullptr;
     }
 
     for (auto baseClass : recordDecl->bases()) {
-        if (CXXRecordDecl *record = clazy::recordFromBaseSpecifier(baseClass); isQObject(record)) {
+        if (CXXRecordDecl *record = clazy::recordFromBaseSpecifier(baseClass); isQObject(record, qtNamespace)) {
             return record;
         }
     }
@@ -326,9 +339,9 @@ clang::CXXRecordDecl *clazy::getQObjectBaseClass(clang::CXXRecordDecl *recordDec
     return nullptr;
 }
 
-bool clazy::isConnect(FunctionDecl *func)
+bool clazy::isConnect(FunctionDecl *func, const std::string &qtNamespace)
 {
-    return func && func->getQualifiedNameAsString() == "QObject::connect";
+    return func && func->getQualifiedNameAsString() == clazy::qtNamespaced("QObject::connect", qtNamespace);
 }
 
 bool clazy::connectHasPMFStyle(FunctionDecl *func)
@@ -350,7 +363,7 @@ bool clazy::connectHasPMFStyle(FunctionDecl *func)
     return true;
 }
 
-CXXMethodDecl *clazy::pmfFromConnect(CallExpr *funcCall, int argIndex)
+CXXMethodDecl *clazy::pmfFromConnect(CallExpr *funcCall, int argIndex, const std::string &qtNamespace)
 {
     if (!funcCall) {
         return nullptr;
@@ -380,10 +393,10 @@ CXXMethodDecl *clazy::pmfFromConnect(CallExpr *funcCall, int argIndex)
             }
         }
     }
-    return pmfFromExpr(expr);
+    return pmfFromExpr(expr, qtNamespace);
 }
 
-CXXMethodDecl *clazy::pmfFromExpr(Expr *expr)
+CXXMethodDecl *clazy::pmfFromExpr(Expr *expr, const std::string &qtNamespace)
 {
     if (auto *uo = dyn_cast<UnaryOperator>(expr)) {
         return pmfFromUnary(uo);
@@ -409,23 +422,23 @@ CXXMethodDecl *clazy::pmfFromExpr(Expr *expr)
         }
 
         const std::string className = record->getQualifiedNameAsString();
-        if (className != "QNonConstOverload" && className != "QConstOverload") {
+        if (className != clazy::qtNamespaced("QNonConstOverload", qtNamespace) && className != clazy::qtNamespaced("QConstOverload", qtNamespace)) {
             return nullptr;
         }
 
         return pmfFromUnary(dyn_cast<UnaryOperator>(call->getArg(1)));
     } else if (auto *staticCast = dyn_cast<CXXStaticCastExpr>(expr)) {
-        return pmfFromExpr(staticCast->getSubExpr());
+        return pmfFromExpr(staticCast->getSubExpr(), qtNamespace);
     } else if (auto *callexpr = dyn_cast<CallExpr>(expr)) {
         // QOverload case, go deeper one level to get to the UnaryOperator
         if (callexpr->getNumArgs() == 1) {
-            return pmfFromExpr(callexpr->getArg(0));
+            return pmfFromExpr(callexpr->getArg(0), qtNamespace);
         }
     } else if (auto *matTempExpr = dyn_cast<MaterializeTemporaryExpr>(expr)) {
         // Qt6 PMF, go deeper one level to get to the UnaryOperator
-        return pmfFromExpr(matTempExpr->getSubExpr());
+        return pmfFromExpr(matTempExpr->getSubExpr(), qtNamespace);
     } else if (auto *impl = dyn_cast<ImplicitCastExpr>(expr)) {
-        return pmfFromExpr(impl->getSubExpr());
+        return pmfFromExpr(impl->getSubExpr(), qtNamespace);
     }
 
     return nullptr;
