@@ -9,30 +9,19 @@
 
 #include "checkbase.h"
 
-#include <string>
-
-class QColorFromLiteral_Callback;
-namespace clang
-{
-namespace ast_matchers
-{
-class MatchFinder;
-} // namespace ast_matchers
-} // namespace clang
-
 /**
  * See README-qcolor-from-literal.md for more info.
  */
 class QColorFromLiteral : public CheckBase
 {
 public:
-    explicit QColorFromLiteral(const std::string &name, ClazyContext *context);
+    using CheckBase::CheckBase;
     ~QColorFromLiteral() override;
     void VisitStmt(clang::Stmt *stmt) override;
     void registerASTMatchers(clang::ast_matchers::MatchFinder &) override;
 
 private:
-    ClazyAstMatcherCallback *const m_astMatcherCallBack;
+    std::unique_ptr<ClazyAstMatcherCallback> m_astMatcherCallBack;
 };
 
 #endif
