@@ -34,7 +34,7 @@ void QEnums::VisitMacroExpands(const Token &MacroNameTok, const SourceRange &ran
         // We simply check if :: is present because it's very cumbersome to to check for different classes when dealing with the pre-processor
 
         CharSourceRange crange = Lexer::getAsCharRange(range, sm(), lo());
-        std::string text = static_cast<std::string>(Lexer::getSourceText(crange, sm(), lo()));
+        std::string text = Lexer::getSourceText(crange, sm(), lo()).str();
         if (clazy::contains(text, "::")) {
             return;
         }
