@@ -9,16 +9,17 @@
 
 #include "checkbase.h"
 
-#include <string>
-
 /**
  * See README-qhash-namespace.md for more info.
  */
 class QHashNamespace : public CheckBase
 {
 public:
-    explicit QHashNamespace(const std::string &name, ClazyContext *context);
+    using CheckBase::CheckBase;
     void VisitDecl(clang::Decl *decl) override;
+
+private:
+    std::string fullyQualifiedParamName(clang::ParmVarDecl *firstArg);
 };
 
 #endif
