@@ -12,8 +12,6 @@
 
 #include "checkbase.h"
 
-#include <string>
-
 namespace clang
 {
 class VarDecl;
@@ -34,12 +32,12 @@ struct QualTypeClassification;
 class FunctionArgsByRef : public CheckBase
 {
 public:
-    FunctionArgsByRef(const std::string &name, ClazyContext *context);
+    using CheckBase::CheckBase;
     void VisitDecl(clang::Decl *decl) override;
     void VisitStmt(clang::Stmt *stmt) override;
 
 private:
-    static bool shouldIgnoreClass(clang::CXXRecordDecl *);
+    bool shouldIgnoreClass(clang::CXXRecordDecl *);
     static bool shouldIgnoreOperator(clang::FunctionDecl *);
     static bool shouldIgnoreFunction(clang::FunctionDecl *);
     void processFunction(clang::FunctionDecl *);
