@@ -27,8 +27,8 @@ public:
     }
     void run(const MatchFinder::MatchResult &result) override
     {
-        if (const auto *callExpr = result.Nodes.getNodeAs<CXXMemberCallExpr>("callExpr")) {
-            if (callExpr->getMethodDecl()->isConst() && !callExpr->getMethodDecl()->getReturnType()->isVoidType()) {
+        if (const auto *callExpr = result.Nodes.getNodeAs<CXXMemberCallExpr>("opCallExpr")) {
+            if (const auto *methodDecl = callExpr->getMethodDecl(); methodDecl && methodDecl->isConst() && !methodDecl->getReturnType()->isVoidType()) {
                 const auto &parents = result.Context->getParents(*callExpr);
 
                 if (parents[0].get<Stmt>() != nullptr && parents[0].get<Decl>() == nullptr) {
@@ -41,9 +41,7 @@ public:
                         && clazy::qualifiedMethodName(callExpr->getMethodDecl()) != "QMetaType::registerHelper") {
                         m_check->emitWarning(callExpr->getExprLoc(), "Result of const member function is not used.");
                     }
-                }
-
-                else if (parents[0].get<Decl>() != nullptr && parents[0].get<Stmt>() == nullptr) {
+                } else if (parents[0].get<Decl>() != nullptr && parents[0].get<Stmt>() == nullptr) {
                     if (!llvm::dyn_cast<VarDecl>(parents[0].get<Decl>()) && !llvm::dyn_cast<CXXConstructorDecl>(parents[0].get<Decl>())) {
                         m_check->emitWarning(callExpr->getExprLoc(), "Result of const member function is not used.");
                     }
@@ -53,19 +51,10 @@ public:
     }
 };
 
-UnusedResultCheck::UnusedResultCheck(const std::string &name, ClazyContext *context)
-    : CheckBase(name, context, Option_CanIgnoreIncludes)
-    , m_astMatcherCallBack(std::make_unique<Caller>(this))
-{
-}
-
 UnusedResultCheck::~UnusedResultCheck() = default;
 
-void UnusedResultCheck::VisitStmt(Stmt *stmt)
-{
-}
-
 void UnusedResultCheck::registerASTMatchers(MatchFinder &finder)
 {
-    finder.addMatcher(cxxMemberCallExpr().bind("callExpr"), m_astMatcherCallBack.get());
+    m_astMatcherCallBack = std::make_unique<Caller>(this);
+    finder.addMatcher(cxxMemberCallExpr().bind("opCallExpr"), m_astMatcherCallBack.get());
 }
