@@ -5,7 +5,7 @@ struct A {};
 struct NonNamespacedGadget {
     Q_GADGET
 };
-
+namespace TestMe { class Dummy {};}
 namespace NS {
     struct MyType {};
 
@@ -92,15 +92,37 @@ public Q_SLOTS:
     inline void nestedNotFullyQualifiedGeneric(QDBusPendingReply<std::shared_ptr<MyList>>) {} // WARN
     inline const MyList& notQualWithModifier() {return lst;};
     DummyListAlias<int> myList() { return {1,2,3};};
+
+    // const modifiers
+    inline std::shared_ptr<const QualMe> returnSharedPtrNotQual() // WARN
+    {
+        return std::shared_ptr<const QualMe>(new QualMe());
+    }
+    inline std::shared_ptr<const MyObj2::QualMe> returnSharedPtr()
+    {
+        return std::shared_ptr<const QualMe>(new QualMe());
+    }
+    inline std::shared_ptr<const     MyObj2::QualMe> returnSharedPtrSpaces()
+    {
+        return std::shared_ptr<const QualMe>(new QualMe());
+    }
+    inline const MyObj2::QualMe returnConstNoGeneric()
+    {
+        return QualMe();
+    }
+    Q_INVOKABLE TestMe::Dummy *qual1() const;
+    Q_INVOKABLE TestMe::Dummy* qual2() const;
+    Q_INVOKABLE QualMe * unqualifiedPtr() const;
 private:
     MyList lst;
 };
-
 Q_DECLARE_METATYPE(MyObj2::QualMe);
 Q_DECLARE_METATYPE(std::shared_ptr<MyObj2::MyList>);
 
 #if QT_VERSION_MAJOR == 5
 #include "main.qt5.moc_"
+#elif Q_MOC_OUTPUT_REVISION == 69
+#include "main.qt6.moc_69"
 #else
 #include "main.qt6.moc_"
 #endif
